<template>
  <ModalDialog
    ref="createModal"
    is-page
    @close="$router.push({ name: 'admin.user_roles' })"
  >
    <ModalHeader>
      <ModalTitle>{{ $t("app.admin.user_roles.create.title") }}</ModalTitle>
    </ModalHeader>
    <ModalForm @submit="submit">
      <template #default>
        <AlertError v-if="form.errors && form.errors?.unknown">
          {{ form.errors.unknown }}
        </AlertError>
        <FormInput
          id="name"
          :errors="form.errors.name"
        >
          <FormLabel>{{ $t("app.admin.user_roles.form.name") }}</FormLabel>
          <FormText
            v-model="form.values.name"
            autocomplete="off"
            name="name"
            required
          />
        </FormInput>
        <FormInput
          id="permissions"
          :errors="form.errors.permissions"
        >
          <FormLabel>{{ $t("app.admin.user_roles.form.permissions") }}</FormLabel>
          <UserRolePermissionsSelect
            v-model="form.values.permissions"
            required
          />
        </FormInput>
      </template>
      <template #footer>
        <FormSubmit
          class="btn btn-black"
          :processing="form.isFetching"
        >
          {{ $t("app.admin.user_roles.create.submit") }}
        </FormSubmit>
      </template>
    </ModalForm>
  </ModalDialog>
</template>

<script setup lang="ts">
import ModalDialog from "@/js/contexts/shared/ui/components/modal/ModalDialog.vue";
import useModal from "@/js/contexts/shared/composables/useModal";
import useForm from "@/js/contexts/shared/composables/useForm";
import type { UserRoleCreate } from "@/js/contexts/shared/models/UserRole";
import ModalForm from "@/js/contexts/shared/ui/components/modal/ModalForm.vue";
import ModalHeader from "@/js/contexts/shared/ui/components/modal/ModalHeader.vue";
import ModalTitle from "@/js/contexts/shared/ui/components/modal/ModalTitle.vue";
import FormLabel from "@/js/contexts/form/ui/components/FormLabel.vue";
import FormInput from "@/js/contexts/form/ui/components/FormInput.vue";
import FormText from "@/js/contexts/form/ui/components/FormText.vue";
import AlertError from "@/js/contexts/shared/ui/components/alert/AlertError.vue";
import FormSubmit from "@/js/contexts/form/ui/components/FormSubmit.vue";
import UserRolePermissionsSelect from "@/js/contexts/admin/user-roles/ui/components/UserRolePermissionsSelect.vue";
import useNotification from "@/js/contexts/shared/composables/useNotification";

const emit = defineEmits<{
  fetch: [];
}>();

const { t } = useI18n();
const { successNotification } = useNotification();
const createModal = ref<InstanceType<typeof ModalDialog>>();
const modal = useModal(createModal);
const form = useForm<UserRoleCreate>({
  name: "",
  permissions: [],
});

const submit = () => {
  form.post("/api/admin/user-roles", {
    onSuccess: () => {
      emit("fetch");
      modal.close();
      successNotification(t("app.admin.user_roles.create.success"));
    },
  });
};
</script>
